==> auto-depends-1.1.13-sources.jar: org/jvnet/hk2/component/InhabitantActivator.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2007-2011 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.jvnet.hk2.component;

import org.jvnet.hk2.annotations.Contract;
import org.jvnet.hk2.component.internal.runlevel.DefaultRunLevelService;

/**
 * Contract for handling the activation and releasing of an inhabitant.  Useful
 * when the inhabitant needs to be activated in a particular thread context for
 * example.
 * 
 * @see RunLevelService
 * 
 * @author Jeff trent
 *
 * @since 3.1
 */
@Contract
public interface InhabitantActivator {

  /**
   * Implementations are generally expected to call {@link Inhabitant#get()} at
   * some point.
   * <p>
   * The {@link DefaultRunLevelService} calls activate for all Inhabitants qualifying
   * in the activated RunLevel regardless of whether or not they need activation. 
   * 
   * @param inhabitant the inhabitant to activate
   */
  void activate(Inhabitant<?> inhabitant);
  
  /**
   * Implementations are generally expected to call {@link Inhabitant#release()} at
   * some point.
   * <p>
   * The {@link DefaultRunLevelService} calls deactivate for all Inhabitants qualifying
   * in the activated RunLevel regardless of whether or not they need releasing. 
   * 
   * @param inhabitant the inhabitant to release
   */
  void deactivate(Inhabitant<?> inhabitant);

}

==> auto-depends-1.6.12-sources.jar: org/jvnet/hk2/component/InhabitantActivator.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2007-2011 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.jvnet.hk2.component;

import java.util.concurrent.TimeUnit;
import java.util.concurrent.TimeoutException;

import org.jvnet.hk2.annotations.Contract;
import org.jvnet.hk2.component.internal.runlevel.DefaultRunLevelService;

/**
 * Contract for handling the activation and releasing of an inhabitant.  Useful
 * when the inhabitant needs to be activated in a particular thread context for
 * example.
 * 
 * @see RunLevelService
 * 
 * @author Jeff trent
 *
 * @since 3.1
 */
@Contract
public interface InhabitantActivator {

  /**
   * Implementations are generally expected to call {@link Inhabitant#get()} at
   * some point.
   * 
   * <p/>
   * The {@link DefaultRunLevelService} calls activate for all Inhabitants qualifying
   * in the activated RunLevel regardless of whether or not they need activation. 
   * 
   * @param inhabitant the inhabitant to activate
   */
  void activate(Inhabitant<?> inhabitant);
  
  /**
   * Implementations are generally expected to call {@link Inhabitant#release()} at
   * some point.
   * 
   * <p/>
   * The {@link DefaultRunLevelService} calls deactivate for all Inhabitants qualifying
   * in the activated RunLevel regardless of whether or not they need releasing. 
   * 
   * @param inhabitant the inhabitant to release
   */
  void deactivate(Inhabitant<?> inhabitant);
  
  /**
   * Called after all {@link #activate(Inhabitant)} and {@link #deactivate(Inhabitant)}
   * calls are made to wait for completion of a progression to a particular run level.
   * This is useful in the case where the implementation is asynchronous in nature.
   * 
   * <p/>
   * Generally, there is one awaitCompletion() call per RunLevel being processed.
   */
  void awaitCompletion() throws InterruptedException;

  /**
   * Called after all {@link #activate(Inhabitant)} and {@link #deactivate(Inhabitant)}
   * calls are made to wait for completion of a progression to a particular run level.
   * This is useful in the case where the implementation is asynchronous in nature.
   * 
   * <p/>
   * Generally, there is one awaitCompletion() call per RunLevel being processed.
   */
  void awaitCompletion(long timeout, TimeUnit unit) throws InterruptedException, TimeoutException;

}
